@@ -1,7 +1,7 @@
 libs <- function (Lib)
 {
     if (missing(Lib))
-        print(.packages(all = TRUE), q = FALSE)
+        print(.packages(all.available = TRUE), q = FALSE)
     else eval(parse(text = paste("library(help=",
 as.character(substitute(Lib)),")")))
 }
