@@ -5,7 +5,7 @@ pasteRound <- function (..., digits=16, sep=" ", collapse=NULL) {
       character(0)
     else ""
   else{
-    for(i in seq(along=args))
+    for(i in seq_along(args))
       if(is.numeric(args[[i]])) args[[i]] <-  as.character(round(args[[i]], digits))
       else args[[i]] <- as.character(args[[i]])
    paste(args, sep, collapse)
